@@ -82,10 +82,12 @@ def cli(info: Info, verbose: int):
 @click.option('--path', default=os.getcwd(), help='Path to folder containing kodexa.yml')
 @click.option('--url', default=KodexaPlatform.get_url(), help='The URL to the Kodexa server')
 @click.option('--org', help='The slug for the organization to deploy to', required=True)
+@click.option('--slug', help='The slug to deploy the model to', required=False)
+@click.option('--version', help='The version to deploy the model to', required=False)
 @click.option('--token', default=KodexaPlatform.get_access_token(), help='Access token')
 @cli.command()
 @pass_info
-def push_model(_: Info, path: str, url: str, org: str, token: str):
+def push_model(_: Info, path: str, url: str, org: str, token: str, slug: str, version: str):
     """Deploy extension pack to a Kodexa platform instance
     """
 
@@ -99,8 +101,8 @@ def push_model(_: Info, path: str, url: str, org: str, token: str):
         import yaml
         model_meta = yaml.safe_load(model_meta_file)
 
-    slug = model_meta["slug"]
-    version = model_meta["version"]
+    slug = slug if slug else model_meta["slug"]
+    version = version if version else model_meta["version"]
     model_meta["type"] = "model"
 
     from kodexa import RemoteModelStore
@@ -191,16 +193,17 @@ def apply(_: Info, object_type: str, ref: Optional[str], file: str, token: str,
 @click.argument('ref', required=False)
 @click.option('--url', default=KodexaPlatform.get_url(), help='The URL to the Kodexa server')
 @click.option('--token', default=KodexaPlatform.get_access_token(), help='Access token')
+@click.option('--query', default="*", help='Limit the results using a query')
 @click.option('--path', default=None, help='JQ path to content you want')
 @click.option('--format', default=None, help='The format to output (json, yaml)')
 @pass_info
-def get(_: Info, object_type: str, ref: Optional[str], url: str, token: str, path: str = None, format=None):
+def get(_: Info, object_type: str, ref: Optional[str], url: str, token: str, query: str, path: str = None, format=None):
     """
     List the instance of the object type
     """
     KodexaPlatform.set_url(url)
     KodexaPlatform.set_access_token(token)
-    KodexaPlatform.get(object_type, ref, path, format)
+    KodexaPlatform.get(object_type, ref, path, format, query)
 
 
 @cli.command()
